@@ -9,16 +9,16 @@
 #include "individualmailcomponentfactory.h"
 
 #include <CalendarSupport/KCalPrefs>
-#include <CalendarSupport/Utils>
 
-#include <AkonadiCore/TagFetchScope>
-#include <Item>
-#include <ItemDeleteJob>
-#include <ItemFetchJob>
-#include <ItemFetchScope>
-#include <ItemMoveJob>
-#include <Monitor>
-#include <Session>
+#include <Akonadi/CalendarUtils>
+#include <Akonadi/Item>
+#include <Akonadi/ItemDeleteJob>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/ItemMoveJob>
+#include <Akonadi/Monitor>
+#include <Akonadi/Session>
+#include <Akonadi/TagFetchScope>
 
 #include "incidenceeditor_debug.h"
 #include <KJob>
@@ -72,15 +72,17 @@ ItemEditorPrivate::ItemEditorPrivate(Akonadi::IncidenceChanger *changer, EditorI
 
     mChanger = changer ? changer : new Akonadi::IncidenceChanger(new IndividualMailComponentFactory(qq), qq);
 
+    // clang-format off
     qq->connect(mChanger,
-                SIGNAL(modifyFinished(int, Akonadi::Item, Akonadi::IncidenceChanger::ResultCode, QString)),
+                SIGNAL(modifyFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,QString)),
                 qq,
-                SLOT(onModifyFinished(int, Akonadi::Item, Akonadi::IncidenceChanger::ResultCode, QString)));
+                SLOT(onModifyFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,QString)));
 
     qq->connect(mChanger,
-                SIGNAL(createFinished(int, Akonadi::Item, Akonadi::IncidenceChanger::ResultCode, QString)),
+                SIGNAL(createFinished(int, Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,QString)),
                 qq,
-                SLOT(onCreateFinished(int, Akonadi::Item, Akonadi::IncidenceChanger::ResultCode, QString)));
+                SLOT(onCreateFinished(int, Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,QString)));
+    // clang-format on
 }
 
 void ItemEditorPrivate::moveJobFinished(KJob *job)
@@ -252,10 +254,7 @@ EditorItemManager::EditorItemManager(ItemEditorUi *ui, Akonadi::IncidenceChanger
     d->mItemUi = ui;
 }
 
-EditorItemManager::~EditorItemManager()
-{
-    delete d_ptr;
-}
+EditorItemManager::~EditorItemManager() = default;
 
 Akonadi::Item EditorItemManager::item(ItemState state) const
 {
@@ -280,7 +279,7 @@ Akonadi::Item EditorItemManager::item(ItemState state) const
     }
     qCDebug(INCIDENCEEDITOR_LOG) << "state = " << state;
     Q_ASSERT_X(false, "EditorItemManager::item", "Unknown enum value");
-    return Akonadi::Item();
+    return {};
 }
 
 void EditorItemManager::load(const Akonadi::Item &item)
@@ -316,9 +315,9 @@ void EditorItemManager::save()
 
     if (d->mItem.isValid()) { // A valid item. Means we're modifying.
         Q_ASSERT(d->mItem.parentCollection().isValid());
-        KCalendarCore::Incidence::Ptr oldPayload = CalendarSupport::incidence(d->mPrevItem);
+        KCalendarCore::Incidence::Ptr oldPayload = Akonadi::CalendarUtils::incidence(d->mPrevItem);
         if (d->mItem.parentCollection() == d->mItemUi->selectedCollection() || d->mItem.storageCollectionId() == d->mItemUi->selectedCollection().id()) {
-            (void) d->mChanger->modifyIncidence(d->mItem, oldPayload);
+            (void)d->mChanger->modifyIncidence(d->mItem, oldPayload);
         } else {
             Q_ASSERT(d->mItemUi->selectedCollection().isValid());
             Q_ASSERT(d->mItem.parentCollection().isValid());
@@ -326,7 +325,7 @@ void EditorItemManager::save()
             qCDebug(INCIDENCEEDITOR_LOG) << "Moving from" << d->mItem.parentCollection().id() << "to" << d->mItemUi->selectedCollection().id();
 
             if (d->mItemUi->isDirty()) {
-                (void) d->mChanger->modifyIncidence(d->mItem, oldPayload);
+                (void)d->mChanger->modifyIncidence(d->mItem, oldPayload);
             } else {
                 auto itemMoveJob = new Akonadi::ItemMoveJob(d->mItem, d->mItemUi->selectedCollection());
                 connect(itemMoveJob, SIGNAL(result(KJob *)), SLOT(itemMoveResult(KJob *)));
@@ -338,7 +337,7 @@ void EditorItemManager::save()
             Q_EMIT itemSaveFinished(EditorItemManager::Modify);
         } else {
             Q_ASSERT(d->mItemUi->selectedCollection().isValid());
-            (void) d->mChanger->createFromItem(d->mItem, d->mItemUi->selectedCollection());
+            (void)d->mChanger->createFromItem(d->mItem, d->mItemUi->selectedCollection());
         }
     }
 }
@@ -349,9 +348,7 @@ void EditorItemManager::setIsCounterProposal(bool isCounterProposal)
     d->mIsCounterProposal = isCounterProposal;
 }
 
-ItemEditorUi::~ItemEditorUi()
-{
-}
+ItemEditorUi::~ItemEditorUi() = default;
 
 bool ItemEditorUi::isValid() const
 {
