@@ -190,8 +190,8 @@ void IncidenceAttachment::removeSelectedAttachments()
     if (KMessageBox::questionYesNo(nullptr,
                                    xi18nc("@info", "Do you really want to remove these attachments?<nl/>%1", labelsStr),
                                    i18nc("@title:window", "Remove Attachments?"),
-                                   KStandardGuiItem::yes(),
-                                   KStandardGuiItem::no(),
+                                   KStandardGuiItem::remove(),
+                                   KStandardGuiItem::cancel(),
                                    QStringLiteral("calendarRemoveAttachments"))
         != KMessageBox::Yes) {
         return;
@@ -276,7 +276,7 @@ void IncidenceAttachment::showAttachment(QListWidgetItem *item)
     }
 }
 
-void IncidenceAttachment::showContextMenu(const QPoint &pos)    // clazy:exclude=function-args-by-value
+void IncidenceAttachment::showContextMenu(const QPoint &pos) // clazy:exclude=function-args-by-value
 {
     const bool enable = mAttachmentView->itemAt(pos) != nullptr;
 
@@ -404,7 +404,8 @@ void IncidenceAttachment::handlePasteOrDrop(const QMimeData *mimeData)
         probablyWeHaveUris = true;
     }
     QMenu menu;
-    QAction *linkAction = nullptr, *cancelAction = nullptr;
+    QAction *linkAction = nullptr;
+    QAction *cancelAction = nullptr;
     if (probablyWeHaveUris) {
         linkAction = menu.addAction(QIcon::fromTheme(QStringLiteral("insert-link")), i18nc("@action:inmenu", "&Link here"));
         // we need to check if we can reasonably expect to copy the objects
@@ -523,6 +524,7 @@ void IncidenceAttachment::setupAttachmentIconView()
     auto layout = new QGridLayout(mUi->mAttachmentViewPlaceHolder);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(mAttachmentView);
+    QWidget::setTabOrder(mUi->mAddButton, mAttachmentView);
 }
 
 // void IncidenceAttachmentEditor::addAttachment( KCalendarCore::Attachment *attachment )
